"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .modeldetails import ModelDetails, ModelDetailsTypedDict
from .payloadindextype import PayloadIndexType, PayloadIndexTypeTypedDict
from mixpeek.types import BaseModel
from typing import Dict, List
from typing_extensions import TypedDict


class AvailableIndexesResponseTypedDict(TypedDict):
    r"""Response schema for available indexes endpoint"""

    embedding_models: Dict[str, ModelDetailsTypedDict]
    payload_indexes: List[PayloadIndexTypeTypedDict]


class AvailableIndexesResponse(BaseModel):
    r"""Response schema for available indexes endpoint"""

    embedding_models: Dict[str, ModelDetails]

    payload_indexes: List[PayloadIndexType]
